# Contributing to viadot

## How to contribute

Before creating a PR, make sure to familiarize yourself with the [Contributing Guide](https://github.com/dyvenia/viadot/blob/main/CONTRIBUTING.md).

## Next steps

To learn advanced `viadot` concepts and usage patterns, see the [advanced usage guide](../advanced_usage/index.md).
